Module: Hexx::Suit::Metrics

Defined in:
lib/hexx/suit/metrics.rb,
lib/hexx/suit/metrics/rubocop.rb,
lib/hexx/suit/metrics/metric_fu.rb,
lib/hexx/suit/metrics/yardstick.rb,
lib/hexx/suit/metrics/metric_fu/base.rb,
lib/hexx/suit/metrics/metric_fu/cane.rb,
lib/hexx/suit/metrics/metric_fu/flay.rb,
lib/hexx/suit/metrics/metric_fu/reek.rb,
lib/hexx/suit/metrics/metric_fu/churn.rb,
lib/hexx/suit/metrics/metric_fu/roodi.rb,
lib/hexx/suit/metrics/metric_fu/saikuro.rb

Overview

Contains metric configurators

Any configurator loads metric settings from a corresponding yaml, sets necessary environments via load method, and then runs the metric via run method.

Configurators loads their own dependencies in a corresponding constructor.

Defined Under Namespace

Classes: MetricFu, Rubocop, Yardstick