Class: Hexx::Suit::Metrics::MetricFu::Base
- Inherits:
-
RSpec::Metrics::Base
- Object
- RSpec::Metrics::Base
- Hexx::Suit::Metrics::MetricFu::Base
- Defined in:
- lib/hexx/suit/metrics/metric_fu/base.rb
Overview
Base class for metrics configured via metric_fu
Class Method Summary collapse
-
.load ⇒ self
Initializes and configures the metric from a corresponding yml.
-
.new ⇒ Hexx::Suit::Metrics::MetricFu
private
Constructs the object and loads 'metric_fu' dependency.
Class Method Details
.load ⇒ self
Initializes and configures the metric from a corresponding yml
28 29 30 31 32 |
# File 'lib/hexx/suit/metrics/metric_fu/base.rb', line 28 def load configure { |metric| .each { |option| add(metric, option) } } super end |
.new ⇒ Hexx::Suit::Metrics::MetricFu
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Constructs the object and loads 'metric_fu' dependency
19 20 21 22 |
# File 'lib/hexx/suit/metrics/metric_fu/base.rb', line 19 def self.new require "metric_fu" super end |