Class: Hexx::Suit::Metrics::Yardstick
- Inherits:
-
RSpec::Metrics::Base
- Object
- RSpec::Metrics::Base
- Hexx::Suit::Metrics::Yardstick
- Defined in:
- lib/hexx/suit/metrics/yardstick.rb
Overview
Prepares and runs yardstick environment from '.hexx-suit.yml'
Class Method Summary collapse
-
.load ⇒ self
Prepares output for the yardstick and sets the YARDSTICK_OUTPUT env.
-
.new ⇒ Hexx::Suit::Metrics::Yardstick
private
Loads yardstick verifier.
-
.run ⇒ undefined
Runs yardstick with options from '.hexx-suit.yml'.
Class Method Details
.load ⇒ self
Prepares output for the yardstick and sets the YARDSTICK_OUTPUT env
22 23 24 25 26 27 |
# File 'lib/hexx/suit/metrics/yardstick.rb', line 22 def load prepare_output set_environment super end |
.new ⇒ Hexx::Suit::Metrics::Yardstick
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Loads yardstick verifier
13 14 15 16 |
# File 'lib/hexx/suit/metrics/yardstick.rb', line 13 def self.new require "yardstick/rake/measurement" super end |
.run ⇒ undefined
Runs yardstick with options from '.hexx-suit.yml'
33 34 35 |
# File 'lib/hexx/suit/metrics/yardstick.rb', line 33 def run measurement.yardstick_measure end |